@@ -49,7 +49,7 @@ void composition_game_close(){
 		g_object_unref(chum_get_pair_composition());
 		chum_set_pair_composition(NULL);
 		//Go back to pair-game menu.
-		themeselection_going_to(NULL,NULL,NULL,NULL);
+		themeselection_going_to(NULL,NULL);
 	}
 
 	else { //single player game: respect 'view_to_go_when_end'
@@ -67,6 +67,7 @@ static void hide_save_menu(){
 
 void composition_game_quit_without_saving_clicked (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("composition_game_quit_without_saving",J_LOG_USER_ACTION);
+	jammo_mentor_shut_up(jammo_mentor_get_default());
 	composition_game_close();
 }
 
@@ -74,7 +75,7 @@ void composition_game_back_to_game_clicked (TangleButton* tanglebutton, gpointer
 	cem_add_to_log("composition-game back to game from saving-menu clicked",J_LOG_USER_ACTION);
 	hide_save_menu();
 	//technically we haven't changed the view, so mentor_idle_speech is not changed automatically
-	tangle_action_execute(TANGLE_ACTION(jammo_get_object_by_id("compositiongame-mentor-action")));
+	tangle_activity_activate(TANGLE_ACTIVITY(jammo_get_object_by_id("compositiongame-mentor-activity")));
 }
 
 
@@ -206,14 +207,10 @@ jammo_theme* composition_game_start_theme(const gchar* name, int variation, Clut
 	g_free(message);
 
 	already_quitted = FALSE;
-	GError* error = NULL;
 	//Change Background for this theme
 	gchar *background_image_name = g_strdup_printf("%s/themes/%s/background.png",DATA_DIR,name);
 	ClutterActor *background;
-	if(!(background=clutter_texture_new_from_file(background_image_name, &error))){
-	fprintf(stderr, "%s\n",  error->message);
-            g_error_free(error);
-	}
+	background=tangle_texture_new(background_image_name);
 	g_free(background_image_name);
 
 
