@@ -127,6 +127,8 @@ gint format_version = 1; //jammo-0.7.7 and all before that is format_version=1
 			sub_node = json_object_get_member (sub_object, "samples");
 			if (format_version==1) //Legacy1
 				load_this_sample_array_to_this_track_view_legacy1(sub_node,track_view,theme,theme_name,variation); //static
+			else if (format_version==2) //Legacy2
+				load_this_sample_array_to_this_track_view_legacy2(sub_node,track_view,FALSE); //FALSE=non-reactive
 			else
 				load_this_sample_array_to_this_track_view(sub_node,track_view,FALSE); //FALSE=non-reactive
 
