@@ -266,7 +266,15 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 	//printf("Song '%s' pressed: \n",song->fullpath);
 
 	gchar* image_filename;
-	image_filename = g_strdup_printf("%s/background.png",path);
+	//check if there are language specific image
+	image_filename = g_strdup_printf("%s/background%s.png",path,chum_get_selected_language());
+	int fd_0 = open(image_filename,O_RDONLY);
+	if (fd_0 == -1) //File not found -> use without suffix
+		{
+		g_free(image_filename);
+		image_filename = g_strdup_printf("%s/background.png",path);
+		}
+
 	//printf("image_filename = '%s'\n",image_filename);
 
 	ClutterActor *texture = tangle_texture_new(image_filename);
@@ -426,6 +434,8 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 
 		g_signal_connect(timeline, "completed", G_CALLBACK(song_view_showed), sequencer);
 
+		ClutterColor red = { 255, 0, 0, 128 };
+		recording_cursor = singinggame_add_cursor(&red, sequencer, view, FALSE);
 	}
 	else {
 		//printf("song started from cupboard\n");
@@ -462,10 +472,11 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 
 		g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped_from_cupboard),view);
 		g_signal_connect(timeline, "completed", G_CALLBACK(start_sequencer_after_animation), sequencer);
-		}
 
-	ClutterColor red = { 255, 0, 0, 128 };
-	recording_cursor = singinggame_add_cursor(&red, sequencer, view, FALSE);
+		ClutterColor color = { 0,255,255, 128 };
+		//Use existing recordin_cursor, even this is only playback
+		recording_cursor = singinggame_add_cursor(&color, sequencer, view, TRUE); //seekable
+		}
 
 	return FALSE;
 }
@@ -531,8 +542,16 @@ And add signal handler.
 void song_prepare_icon(jammo_song* song){
 	gchar* folder=song->fullpath;
 	gchar* image_filename;
-	image_filename = g_strdup_printf("%s/background.png",folder);
-	//printf("image = '%s'\n",image_filename);
+	image_filename = g_strdup_printf("%s/background%s.png",folder,chum_get_selected_language());
+
+	//check if there are language specific image
+	int fd = open(image_filename,O_RDONLY);
+	if (fd == -1) //File not found -> use without suffix
+		{
+		g_free(image_filename);
+		image_filename = g_strdup_printf("%s/background.png",folder);
+		}
+
 
 	//Default values:
 	gfloat xoff    = 0.0;
@@ -540,9 +559,18 @@ void song_prepare_icon(jammo_song* song){
 	gfloat x_size  = 800.0;
 	gfloat y_size  = 480.0;
 
-	gchar* inputFilename = g_strdup_printf("%s/icon.json",folder);
-	icon_offset_from_json(inputFilename, &xoff, &yoff, &x_size,&y_size);
-	g_free(inputFilename);
+	//check if there are language specific icon*.json
+	gchar* icon_json_filename = g_strdup_printf("%s/icon%s.json",folder,chum_get_selected_language());
+	fd = open(icon_json_filename,O_RDONLY);
+	if (fd == -1) //File not found -> use without suffix
+		{
+		g_free(icon_json_filename);
+		icon_json_filename = g_strdup_printf("%s/icon.json",folder);
+		}
+	icon_offset_from_json(icon_json_filename, &xoff, &yoff, &x_size,&y_size);
+	//printf("song.c: image_filename = '%s'\n",image_filename);
+	//printf("song.c: icon_json_filename = '%s'\n",icon_json_filename);
+	g_free(icon_json_filename);
 
 	//printf("Boundaries: %lf,%lf,%lf,%lf\n", xoff,yoff,x_size,y_size);
 	song->xoff = xoff;
