@@ -11,6 +11,7 @@ typedef struct{
 	ClutterActor* body;
 	ClutterActor* hair;
 	ClutterActor* head;
+	ClutterActor* eyes;
 	ClutterActor* instrument;
 }Avatar;
 
@@ -22,5 +23,5 @@ gchar* avatar_give_username_for_this_id(guint32 avatar_id);
 
 gboolean avatar_unserialize_image(Avatar* avatar, guint32 serialized_image);
 guint32 avatar_serialize_image(Avatar* avatar);
-void avatar_shrink(Avatar* avatar, ClutterContainer *avatarBackground);
+void avatar_shrink(Avatar* avatar);
 #endif /* AVATAR_H */
