@@ -22,6 +22,7 @@ Cancel-button returns without modification.
 #include "../../configure.h"
 #include "../file_helper.h"
 #include "sequencer.h"
+#include "sequencer_track_view.h"
 #include <string.h>
 #include "../../cem/cem.h"
 
@@ -111,7 +112,7 @@ gboolean backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 	else
 		prefix ="Sa";
 
-	gchar* backing_track_filename = g_strdup_printf("%s/backingtracks/%s_%s_$t_$p%s.ogg",AUDIO_DIR,prefix,name,postfix);
+	gchar* backing_track_filename = g_strdup_printf("backingtracks/%s_%s_$t_$p%s.ogg",prefix,name,postfix);
 	message=g_strdup_printf("Backintrack-selection: looking file '%s' ",backing_track_filename);
 	cem_add_to_log(message,J_LOG_USER_ACTION);
 	g_free(message);
@@ -201,15 +202,53 @@ gboolean backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer
 			//audio
 			JammoTrack* track = NULL;
 			g_object_get(track_view,"track",&track,NULL);
-			if (track) {
-				g_object_set(track,"filename",last_played_filename,NULL);
-			} else {
-					cem_add_to_log("Backintrack-selection: No track found.",J_LOG_FATAL);
+			if (!track) {
+				cem_add_to_log("Backintrack-selection: No track found.",J_LOG_FATAL);
 				return TRUE;
 			}
 
+			g_object_set(track,"filename",last_played_filename,NULL);
+			//Number of slots is changed.
+			JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+			guint64 duration_of_sequencer = jammo_sequencer_get_duration(sequencer);
+			guint64 duration_of_track = jammo_track_get_duration(track);
+
+
+			gchar* message = g_strdup_printf("Backintrack changed: old sequencer duration was: %" G_GUINT64_FORMAT "", duration_of_sequencer);
+			cem_add_to_log(message,J_LOG_DEBUG);
+			g_free(message);
+
+			message = g_strdup_printf("Backintrack changed: new sequencer duration will be: %" G_GUINT64_FORMAT "", duration_of_track);
+			cem_add_to_log(message,J_LOG_DEBUG);
+			g_free(message);
+
+			sequencer_track_view_fix_cursor();
+
+			ClutterActor* container = jammo_get_actor_by_id("fullsequencer-container-for-tracks");
+			TangleActorIterator actor_iterator;
+			ClutterActor* child;
+
+			for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(container), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+				if (JAMMO_IS_EDITING_TRACK_VIEW(child)) {
+					guint64 duration_of_one_slot;
+					g_object_get(child,"slot-duration",&duration_of_one_slot,NULL);
+					gint new_number_of_slots = duration_of_track/duration_of_one_slot;
+					g_object_set(child,"n-slots",new_number_of_slots,NULL);
+
+					message = g_strdup_printf("New number of slots for %s: %d",clutter_actor_get_name(child),new_number_of_slots);
+					cem_add_to_log(message,J_LOG_DEBUG);
+					g_free(message);
+
+					int old_number_of_slots = duration_of_sequencer/duration_of_one_slot;
+					int i;
+					for (i=new_number_of_slots;i<old_number_of_slots;i++){
+						jammo_editing_track_view_remove_jammo_sample_button_from_slot(JAMMO_EDITING_TRACK_VIEW(child),i);
+					}
+				}
+			}
+
 			//image
-			gchar* image_file = g_build_filename(DATA_DIR, "backingtracks",image_name_for_last_played,NULL);
+			gchar* image_file = g_build_filename("backingtracks",image_name_for_last_played,NULL);
 			//printf ("image_file '%s'\n",image_file);
 			ClutterActor* new_back = tangle_texture_new(image_file);
 			if (new_back==NULL) {
