@@ -16,6 +16,7 @@ This file contains the functionality of discuss menu.
 #include "profile_viewer.h"
 #include "../../cem/cem.h"
 #include "avatar.h"
+#include "avatar_editor.h"
 
 //File containing topic names (etc)
 #define FORUM_TOPICS_FILE "forum_topics.json"
@@ -47,7 +48,7 @@ static gboolean load_threads_from_server(gchar* currentThread);
 static gboolean sendJammoThread(gchar* thread_path, gchar* messages_path);
 static gboolean discuss_change_to_threads_view(ClutterActor * element);
 static gboolean parse_discussions_from_file(gchar* filename, int type);
-static gboolean discuss_send_thread(gint index, guint32 userid, gchar* sender, const gchar* title, const gchar* msg, gchar* filepath, gchar* time, int msgtype);
+static gboolean discuss_send_thread(gint index_, guint32 userid, const gchar* sender, const gchar* title, const gchar* msg, const gchar* filepath, const gchar* time_, int msgtype);
 static ClutterActor *create_line(int y, int length, int size, ClutterContainer *cont);
 
 /**
@@ -272,7 +273,9 @@ static gboolean addThread(gpointer data, int number){
     	clutter_actor_set_size(text, ((35*12)+30), 51);
 	clutter_text_set_max_length(CLUTTER_TEXT(text), 35);
 
-	avatar_shrink(&avatar, CLUTTER_CONTAINER(avatarbg));
+	set_avatar(&avatar, CLUTTER_ACTOR(avatarbg));
+	avatar_shrink(&avatar);
+
 	ClutterActor *title = tangle_button_new_with_background_actor(text);
 	clutter_actor_set_name(title, thread->json);
 
@@ -462,12 +465,11 @@ gboolean add_new_thread(TangleButton* tanglebutton, gpointer none){
 		gint thread_index = 0;
 		const gchar* title = clutter_text_get_text(CLUTTER_TEXT(titleTextField.text));
 		const gchar* msg = clutter_text_get_text(CLUTTER_TEXT(descriptionTextField.text));
-		gchar *filepath = "";
 		int type = TEXT_COMMENT;
 		char date [80];
 		cem_get_time(date);
 
-		if(!discuss_send_thread(thread_index, user_id, sender, title, msg, filepath, date, type)){
+		if(!discuss_send_thread(thread_index, user_id, sender, title, msg, "", date, type)){
 			cem_add_to_log("Failed to add new thread: error happened while trying to send file.", J_LOG_DEBUG);
 			clutter_text_set_text(CLUTTER_TEXT(error_msg), "Failed to add new thread. Please try again.");
 		}else{
@@ -500,7 +502,7 @@ static void getThread(ClutterActor *element){
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 
-	start_thread_view(/*messages,*/ "discuss", (gchar*)json_path, 0); 
+	start_thread_view( "discuss", json_path, 0);
 	
 }
 
@@ -747,7 +749,7 @@ static gboolean parse_discussions_from_file(gchar* filename, int type) {
 			JsonObject* sub_object = json_node_get_object(discussion_node);
 			JsonNode *sub_node;
 			
-			gchar *id = "";	
+			const gchar* id = "";
 			gint  thread_index = 0;
 			guint32 user_id = 0;
 			const gchar* title = "";
@@ -760,7 +762,7 @@ static gboolean parse_discussions_from_file(gchar* filename, int type) {
 
 			sub_node = json_object_get_member(sub_object, "id"); 
 			if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
-				id = (gchar*)json_node_get_string(sub_node);
+				id = json_node_get_string(sub_node);
 				printf("id: '%s'\n", id);
 			}	
 			sub_node = json_object_get_member(sub_object, "userid"); 
@@ -841,7 +843,7 @@ static gboolean parse_discussions_from_file(gchar* filename, int type) {
 /**
  * Builds json files needed to send a new thread to server
 **/
-static gboolean discuss_send_thread(gint index_, guint32 userid, gchar* sender, const gchar* title, const gchar* msg, gchar* filepath, gchar* time_, int msgtype) {
+static gboolean discuss_send_thread(gint index_, guint32 userid, const gchar* sender, const gchar* title, const gchar* msg, const gchar* filepath, const gchar* time_, int msgtype) {
 	cem_add_to_log("discuss_send_thread",J_LOG_DEBUG);
 	
 	//TODO: re-download current thread file because it might have changed meanwhile
