@@ -267,6 +267,24 @@ gboolean instrument_goeditor_clicked (TangleActor* actor, gpointer data){
 	return TRUE;
 }
 
+
+gboolean instrumentview_goto_startmenu (TangleButton* tanglebutton, gpointer none){
+	cem_add_to_log("From  instrumentview to startmenu clicked",J_LOG_USER_ACTION);
+	end_jamming();
+
+	clutter_actor_show (jammo_get_actor_by_id("startmenu-view"));
+	return TRUE;
+}
+
+
+gboolean instrumentview_goto_instrumentmenu (TangleButton* tanglebutton, gpointer none){
+	cem_add_to_log("From  instrument-gui to instrumentmenu clicked",J_LOG_USER_ACTION);
+	end_jamming();
+
+	clutter_actor_show (jammo_get_actor_by_id("instrumentmenu-view"));
+	return TRUE;
+}
+
 //////////////////////////
 static gulong handler_for_update_marker = 0;
 
@@ -329,8 +347,10 @@ static void end_jamming() {
 	if (recording)
 		jammo_sequencer_stop (JAMMO_SEQUENCER (static_sequencer));
 
-	if (ad_hoc_slider_track)
+	if (ad_hoc_slider_track) {
 		g_signal_handler_disconnect (ad_hoc_slider_track,handler_for_update_marker);
+		ad_hoc_slider_track=NULL;
+	}
 
 	jammo_sequencer_stop(ad_hoc_sequencer);
 	g_object_unref(ad_hoc_sequencer);
