@@ -100,7 +100,7 @@ void start_sequencer_with_this_file(ClutterActor *actor, gpointer none)
 	mysongs_end_mysongs();
 
 	const char* filename = clutter_actor_get_name(actor);
-	sequencer_start_with_file((char*)filename);
+	sequencer_start_with_file(filename);
 }
 
 /*
@@ -367,27 +367,26 @@ void mysongs_send_song(ClutterActor *actor)
 	char *all_songs_filepath = g_strdup_printf("%s/all_songs.json", configure_get_temp_directory()); //Only for testing!
 
 	FILE *commentsFile;
-	gboolean coverFound = FALSE;
 	ClutterActor *text = tangle_button_get_normal_background_actor(TANGLE_BUTTON(actor));
 	const gchar * songname = clutter_text_get_text(CLUTTER_TEXT(text));
 	
-	char * cover = "";
-	char * songid = "";
+	gchar* cover =  g_strdup_printf(" "); //TODO: default?
 	const char * filename = clutter_actor_get_name(actor); 
 	guint32 userid = /*gems_profile_manager_get_userid(NULL)*/TEST_USERID;
 
 	char date [80];
 	cem_get_time(date);
 	
-	songid = g_strdup_printf("%d_%s", userid, songname); 	
+	gchar* songid = g_strdup_printf("%d_%s", userid, songname);
 	char * comments = g_strdup_printf("%s/messages_%s.json", configure_get_temp_directory(), songid); 
 	char * label_path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), userid, songname);
 	
 	if(community_utilities_file_exist(label_path)){
-		coverFound = TRUE;
 		
-		if(mysongs_copy_label(label_path, userid, songname)) //we copy the labelfile to temp directory for sending
+		if(mysongs_copy_label(label_path, userid, songname)) { //we copy the labelfile to temp directory for sending
+			g_free(cover);
 			cover = g_strdup_printf("%s/label_%d_%s.csv", configure_get_temp_directory(), userid, songname);
+		}
 	}
 	g_free(label_path);
 	
@@ -514,8 +513,7 @@ void mysongs_send_song(ClutterActor *actor)
 	if(sendJammoSong(filename, cover, comments, all_songs_filepath))
 		printf("sendJammoSong ok\n");
 
-	if(coverFound)
-		g_free(cover);
+	g_free(cover);
 	
 	g_free(all_songs_filepath);
 	g_free(dest_filepath);
