@@ -17,7 +17,7 @@ gboolean sequencer_change_to_sequencer_view(TangleActor *actor, gpointer data);
 gboolean sequencer_change_to_bottom_view(TangleActor *actor, gpointer data);
 void return_to_fullsequencer_gui();
 void fullsequencer_trackview_loaded (TangleActor* trackview, gpointer none);
-void sequencer_start_with_file(gchar* filename);
+void sequencer_start_with_file(const gchar* filename);
 void sequencer_save_project();
 #endif /* _SEQUENCER_H_ */
 
