@@ -538,7 +538,7 @@ ClutterActor* sequencer_loop_give_sample_button_for_this_id(guint id){
 	ClutterActor* sample_button;
 	samplebutton_tuple* new_button=g_list_nth_data(asked_table,id_);
 	gchar* full_image = tangle_lookup_filename(new_button->image);
-	gchar* full_sound = g_strdup_printf("%s/%s", DATA_DIR,new_button->sound);
+	gchar* full_sound = g_strdup_printf("%s", new_button->sound);
 	//printf("new_sample: '%s', '%s'\n",full_image,full_sound);
 	sample_button = jammo_sample_button_new_with_type(type_by_id(id));
 
