@@ -3,6 +3,6 @@
 
 #include <glib.h>
 
-void start_thread_view(gchar *id_, const gchar *params, int index_);
+void start_thread_view(const gchar *id_, const gchar *params, int index_);
 
 #endif /* __SINGLE_THREAD_H__ */
