@@ -8,6 +8,6 @@ This file is for clutter based gui.
 #define STARTMENU_H_
 
 #include <tangle.h>
-void startmenu_goto_startmenu (TangleButton* tanglebutton, gpointer none);
-void startmenu_goto_communitymenu(TangleButton* tanglebutton, gpointer none);
+gboolean startmenu_goto_startmenu (TangleButton* tanglebutton, gpointer none);
+gboolean startmenu_goto_communitymenu(TangleButton* tanglebutton, gpointer none);
 #endif /* STARTMENU_H_ */
