@@ -61,7 +61,7 @@ void start_workshops(){
 
 		ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(songlist.list), TANGLE_TYPE_SCROLL_ACTION);
 
-		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), &songlist);
+		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_utilities_autoscroll_list), &songlist);
 	}
 
 	else 
@@ -70,24 +70,18 @@ void start_workshops(){
 }
 gboolean workshop_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
-	clear_container(songlist.list);
+	community_utilities_clear_container_recursively(songlist.list);
 	start_communitymenu();
 	return TRUE;
 }
 
 gboolean workshop_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
-	clear_container(songlist.list);
+	community_utilities_clear_container_recursively(songlist.list);
 	startmenu_goto_startmenu(tanglebutton, none);
 	return TRUE;
 }
 
-static void start_sequencer_with_this_file(ClutterActor *actor, gpointer none) 
-{
-	const char* filename = clutter_actor_get_name(actor);
-	sequencer_start_with_file((char*)filename);
-}
-
 gboolean workshop_mentor_clicked (TangleButton *tanglebutton, gpointer data)
 {
 	cem_add_to_log("mentor clicked", J_LOG_DEBUG);
@@ -155,8 +149,13 @@ gboolean workshop_add_loop_to_list(char* filename)
 	g_free(colorbar_filename);	
 	g_free(sequencerButton_filename);
 	
-	g_signal_connect_swapped(textButton, "clicked", G_CALLBACK(play_selected_loop), textButton);
-	g_signal_connect (sequencerButton, "clicked", G_CALLBACK (start_sequencer_with_this_file),NULL);
+	//FIXME: use sequencerButton as this used to be:
+	//g_signal_connect_swapped(textButton, "clicked", G_CALLBACK(play_selected_loop), textButton);
+	//g_signal_connect (sequencerButton, "clicked", G_CALLBACK (start_sequencer_with_this_file),NULL);
+
+	g_signal_connect(textButton, "clicked", G_CALLBACK(song_on_clicked_function), NULL);
+	g_object_set(textButton, "hold-timeout", 1500, NULL);
+	g_signal_connect(textButton, "held", G_CALLBACK(song_on_held_function), NULL);
 
 	clutter_container_add_actor(songlist.list, CLUTTER_ACTOR(listContainer));
 	
