@@ -8,8 +8,8 @@ This file contains the functionality of Workshops menu.
 #define WORKSHOPS_H_
 
 void start_workshops();
-void workshop_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
-void workshop_goto_startmenu(TangleButton *tanglebutton, gpointer none);
+gboolean workshop_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
+gboolean workshop_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 
 gboolean workshop_mentor_clicked (TangleButton *tanglebutton, gpointer data);
 gboolean workshop_add_loop_to_list(char* filename);
