@@ -71,6 +71,8 @@ void jammo_game_task_start(JammoGameTask* task) {
 	GSList* slist_item;
 	ClutterActor* actor;
 	
+	g_return_if_fail(JAMMO_IS_GAME_TASK(task));
+	
 	parent = clutter_actor_get_parent(CLUTTER_ACTOR(task->priv->view));
 	g_warn_if_fail(parent != NULL);
 		
@@ -100,6 +102,8 @@ void jammo_game_task_stop(JammoGameTask* task) {
 	GSList* slist_item;
 	ClutterActor* actor;
 
+	g_return_if_fail(JAMMO_IS_GAME_TASK(task));
+
 	clutter_container_foreach(CLUTTER_CONTAINER(task->priv->view), CLUTTER_CALLBACK(clutter_actor_show), NULL);
 	for (slist_item = task->priv->disabled_actors; slist_item; slist_item = slist_item->next) {
 		actor = CLUTTER_ACTOR(slist_item->data);
@@ -112,6 +116,8 @@ GList* jammo_game_task_get_acts(JammoGameTask* task) {
 	GList* act_in_list;
 	Act* act;
 	
+	g_return_val_if_fail(JAMMO_IS_GAME_TASK(task), NULL);
+
 	for (act_in_list = task->priv->acts; act_in_list; act_in_list = act_in_list->next) {
 		act = (Act*)act_in_list->data;
 		act_names = g_list_prepend(act_names, act->name);
@@ -123,6 +129,8 @@ GList* jammo_game_task_get_acts(JammoGameTask* task) {
 void jammo_game_task_add_act(JammoGameTask* task, const gchar* act_name) {
 	Act* act;
 	
+	g_return_if_fail(JAMMO_IS_GAME_TASK(task));
+
 	if (g_list_find_custom(task->priv->acts, act_name, (GCompareFunc)act_compare_name)) {
 		g_warning("An act '%s' already exists in the task.\n", act_name);
 	} else {
@@ -137,6 +145,8 @@ gboolean jammo_game_task_get_act_completed(JammoGameTask* task, const gchar* act
 	GList* act_in_list;
 	Act* act;
 	
+	g_return_val_if_fail(JAMMO_IS_GAME_TASK(task), FALSE);
+
 	if (!(act_in_list = g_list_find_custom(task->priv->acts, act_name, (GCompareFunc)act_compare_name))) {
 		g_warning("An act '%s' does not exists in the task.\n", act_name);
 	} else {
@@ -152,6 +162,8 @@ void jammo_game_task_set_act_completed(JammoGameTask* task, const gchar* act_nam
 	Act* act;
 	guint acts_completed;
 	
+	g_return_if_fail(JAMMO_IS_GAME_TASK(task));
+
 	if (!(act_in_list = g_list_find_custom(task->priv->acts, act_name, (GCompareFunc)act_compare_name))) {
 		g_warning("An act '%s' does not exists in the task.\n", act_name);
 	} else {
@@ -175,11 +187,14 @@ void jammo_game_task_set_act_completed(JammoGameTask* task, const gchar* act_nam
 }
 
 guint jammo_game_task_get_acts_to_complete(JammoGameTask* task) {
+	g_return_val_if_fail(JAMMO_IS_GAME_TASK(task), 0);
 
 	return task->priv->acts_to_complete;
 }
 
 void jammo_game_task_set_acts_to_complete(JammoGameTask* task, guint number_of_tasks) {
+	g_return_if_fail(JAMMO_IS_GAME_TASK(task));
+
 	if (task->priv->acts_to_complete != number_of_tasks) {
 		task->priv->acts_to_complete = number_of_tasks;
 		g_object_notify(G_OBJECT(task), "acts-to-complete");
@@ -191,6 +206,8 @@ guint jammo_game_task_get_acts_completed(JammoGameTask* task) {
 	GList* act_in_list;
 	Act* act;
 	
+	g_return_val_if_fail(JAMMO_IS_GAME_TASK(task), 0);
+
 	for (act_in_list = task->priv->acts; act_in_list; act_in_list = act_in_list->next) {
 		act = (Act*)act_in_list->data;
 		if (act->completed) {
