@@ -49,9 +49,9 @@ const gchar* jammo_mentor_activity_get_idle_speech(JammoMentorActivity* mentor_a
 void jammo_mentor_activity_set_idle_speech(JammoMentorActivity* mentor_activity, const gchar* speech);
 guint jammo_mentor_activity_get_duration(JammoMentorActivity* mentor_activity);
 void jammo_mentor_activity_set_duration(JammoMentorActivity* mentor_activity, guint duration);
-gfloat jammo_mentor_activity_get_offset_x(JammoMentorActivity* mentor_activity);
-void jammo_mentor_activity_set_offset_x(JammoMentorActivity* mentor_activity, gfloat offset_x);
-gfloat jammo_mentor_activity_get_offset_y(JammoMentorActivity* mentor_activity);
-void jammo_mentor_activity_set_offset_y(JammoMentorActivity* mentor_activity, gfloat offset_y);
+void jammo_mentor_activity_get_highlight(JammoMentorActivity* mentor_activity, gfloat* highlight_x_return, gfloat* highlight_y_return);
+void jammo_mentor_activity_set_highlight(JammoMentorActivity* mentor_activity, gfloat highlight_x, gfloat highlight_y);
+gboolean jammo_mentor_activity_get_highlight_set(JammoMentorActivity* mentor_activity);
+void jammo_mentor_activity_set_highlight_set(JammoMentorActivity* mentor_activity, gboolean is_set);
 
 #endif
