@@ -198,7 +198,7 @@ If file is not found (or some other error case) values are not modifed.
  -> Caller should set own defaults before calling,
  (or check against NULL)
 */
-static void read_config_file(char* filename, gboolean* log_stdout, int* log_level,gchar** mentor_lang, gboolean* start_passive_mentor, gboolean* start_advanced) {
+static void read_config_file(char* filename, gboolean* log_stdout, int* log_level,gchar** mentor_lang, gboolean* start_passive_mentor, gboolean* start_advanced, gboolean* fullscreen) {
 	JsonParser *parser;
 	parser = json_parser_new ();
 	g_assert (JSON_IS_PARSER (parser));
@@ -292,6 +292,10 @@ static void read_config_file(char* filename, gboolean* log_stdout, int* log_leve
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
 		*start_advanced= json_node_get_boolean (node);
 
+	node = json_object_get_member (object, "FULLSCREEN");
+	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE)
+		*fullscreen= json_node_get_boolean (node);
+
 	g_object_unref (parser);
 }
 
@@ -331,9 +335,10 @@ int main(int argc, char** argv) {
 	gchar* lang_of_mentor = g_strdup_printf("system");
 	gboolean start_passive_mentor = FALSE;
 	gboolean start_advanced = FALSE; //This affects only for 3-6 years game
+	gboolean fullscreen = FALSE;
 
 	gchar* setting_file = g_strdup_printf("%s/jammo.config",configure_get_jammo_directory());
-	read_config_file(setting_file,&log_to_stdout,&log_level,&lang_of_mentor,&start_passive_mentor,&start_advanced);
+	read_config_file(setting_file,&log_to_stdout,&log_level,&lang_of_mentor,&start_passive_mentor,&start_advanced,&fullscreen);
 	g_free(setting_file);
 
 	//LOGGING
@@ -482,6 +487,8 @@ int main(int argc, char** argv) {
 	clutter_stage_set_fullscreen(CLUTTER_STAGE(stage), TRUE);
 #else
 	clutter_actor_set_size(stage, 800, 480);
+	if (fullscreen) //read from config file
+		clutter_stage_set_fullscreen(CLUTTER_STAGE(stage), TRUE);
 #endif
 
 #ifdef BUFFERER_ENABLED
