@@ -1208,7 +1208,7 @@ gint gems_communication_process_connected()
 	}
 	if(cleanup_required == TRUE) data->communication->connections = gems_cleanup_connections_from_list(data->communication->connections);
 	if(teacher_cleanup_required) gems_teacher_connection_disconnected();
-	
+	songbank_file_sender_loop();
 	return TRUE;
 }
 
@@ -1450,9 +1450,24 @@ gboolean gems_communication_process_data(gems_connection* element)
 			}
 			
 			break;
-		/*case SONGBANK_SERVICE_ID:
+		case SONGBANK_SERVICE_ID:
+			// Check that service is running
+			if(data->service_songbank->enabled == TRUE) success = gems_service_songbank_process_request(element);
+			else
+			{
+				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, SONGBANK_SERVICE_ID);
+				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
+				{
+					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING to %s/%u",
+						ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+					cem_add_to_log(logmsg, J_LOG_ERROR);
+					g_free(logmsg);
+				}
+				gems_clear_message(err);
+				success = FALSE; // TODO change to add a "invalid message" to errors
+			}
 			break;
-		case DATATRANSFER_SERVICE_ID:
+		/*case DATATRANSFER_SERVICE_ID:
 			break;
 		case PROBE_SERVICE_ID:
 			break;*/
