@@ -11,7 +11,7 @@
 
 
 gboolean getJammoData(char *songname, char *userid, char *filename, char *description, char *date, char *json);
-gboolean getJammoSongData(char *jammoSongID);
+gboolean getJammoSongData(char *jammoSongID, char **songname, char **userid, char **filename, char **path, char **description, char **date, char **json);
 gboolean sendJammoFile(gchar *filename);
 
 #endif  /* _COMMUNITY_SERVER_FUNCTIONS_H_ */
