@@ -12,6 +12,7 @@
 #include "gems.h"
 #include "../cem/cem.h"
 #include "collaboration.h"
+#include "../configure.h"
 
 #include "messages.h"
 #include "messagehandler.h"
@@ -21,6 +22,7 @@
 #include <glib.h>
 #include <arpa/inet.h>
 #include <string.h>
+#include "songbank.h"
 
 static gems_components* gems_data = NULL;
 
@@ -60,6 +62,7 @@ gems_components* gems_get_data()
 		gems_data->service_group = NULL;
 		gems_data->service_control = NULL;
 		gems_data->service_mentor = NULL;
+		gems_data->service_songbank = NULL;
 		gems_data->initialized_connections = NULL;
 		gems_data->connection_errorlist = NULL;
 		gems_data->service_collaboration = NULL;
@@ -517,6 +520,9 @@ void jammo_gems_init(int argc, char* argv[])
 
 	// Initialize Control service
 	components->service_control = gems_service_control_init();
+
+	// Initialize Songbank service
+	components->service_songbank = gems_service_songbank_init(components, configure_get_jammo_directory());
 	
 	// Initialize teacher connection
 	components->teacher_connection = gems_teacher_connection_init();
@@ -544,6 +550,7 @@ void jammo_gems_init(int argc, char* argv[])
 		components->service_group->enabled = FALSE;
 		components->service_collaboration->enabled = FALSE;
 		components->service_control->enabled = FALSE;
+		components->service_songbank->enabled = FALSE;
 		
 		/* No need to delete these...
 		ph_c_delete_peerhood(components->ph);
@@ -641,7 +648,11 @@ void jammo_gems_cleanup()
 		if(components->service_mentor->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,MENTOR_SERVICE_NAME);
 		gems_service_mentor_cleanup();
 	}
-	
+	if(components->service_songbank)
+	{
+		if(components->service_songbank->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,SONGBANK_SERVICE_NAME);
+		gems_service_songbank_clean();
+	}
 	// Clear the profile request timer
 	if(components->teacher_profile_request_timer)
 	{
@@ -1675,6 +1686,8 @@ void gems_debugging_show_jammos()
 			else printf("NULL profile\n");
 		}
 		g_list_free(conns); // free the LIST do not touch the data
+		//SendFileToTeacher(FILE_GENERAL, "/opt/jammo/4-players.json");
+		//GetFileFromTeacher(FILE_GENERAL, "jammo.config");
 	}
 	else printf("No connected JamMos\n");
 }
@@ -1814,4 +1827,18 @@ void gems_register_services()
 	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 
+	// Create Songbank service
+	if((serviceport = ph_c_register_service(components->ph,SONGBANK_SERVICE_NAME,"application:jammo,method:songbank")) != 0)
+	{
+		components->service_songbank->enabled = TRUE; //enabled
+		components->service_songbank->port = serviceport;
+		logmsg = g_strdup_printf("gems_networking_register_services: registered %s service.",SONGBANK_SERVICE_NAME);
+	}
+	else
+	{
+		components->service_songbank->enabled = FALSE;
+		logmsg = g_strdup_printf("gems_networking_register_services: cannot register %s service.",SONGBANK_SERVICE_NAME);
+	}
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+	g_free(logmsg);
 }
