@@ -1323,6 +1323,165 @@ gems_message* gems_create_message_mentor_log_message(guint16 type, char *message
 
 }
 
+gems_message* gems_create_message_songbank_search_file_req(guint16 type, char *filename)//Type = filetype (gems_definitions.h)
+{
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + strlen(filename) + 1;
+	
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(SONGBANK_SERVICE_ID);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(SEARCH_FILE_REQ);
+	position = position + sizeof(guint16);
+
+	// Filetype 16 bits
+	*(guint16*)&msg->message[position] = g_htons(type);
+	position = position + sizeof(guint16);
+	
+	// File name
+	g_strlcat(&msg->message[position],filename,msg->length - position);
+	
+	return msg;
+}
+
+gems_message* gems_create_message_songbank_search_file_reply(guint16 type, guint16 status)
+{
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
+	
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(SONGBANK_SERVICE_ID);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(SEARCH_FILE_REPLY);
+	position = position + sizeof(guint16);
+
+	// Status 16 bits
+	*(guint16*)&msg->message[position] = g_htons(status);
+	
+	return msg;
+}
+
+gems_message* gems_create_message_songbank_file_req(guint16 type, char *filename)
+{
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16)+ strlen(filename) + 1;
+	
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(SONGBANK_SERVICE_ID);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(FILE_REQ);
+	position = position + sizeof(guint16);
+
+	// Filetype 16 bits
+	*(guint16*)&msg->message[position] = g_htons(type);
+	position = position + sizeof(guint16);
+	
+	// File name
+	g_strlcat(&msg->message[position],filename,msg->length - position);
+	
+	return msg;
+}
+
+gems_message* gems_create_message_songbank_file_header(guint16 type, guint16 size, char *filename)
+{
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + sizeof(guint16) + strlen(filename) + 1;
+	
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(SONGBANK_SERVICE_ID);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(FILE_HEADER);
+	position = position + sizeof(guint16);
+
+	// Filetype 16 bits
+	*(guint16*)&msg->message[position] = g_htons(type);
+	position = position + sizeof(guint16);
+
+	// File size 16 bits
+	*(guint16*)&msg->message[position] = g_htons(size);
+	position = position + sizeof(guint16);
+	
+	// File name
+	g_strlcat(&msg->message[position],filename,msg->length - position);
+	
+	return msg;
+}
+
+gems_message* gems_create_message_songbank_file_part(guint16 type, guint16 size, guint16 id,char *filecontents)
+{
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + sizeof(guint16) + size + 1 + 1;
+	
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
+	
+	// Service id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(SONGBANK_SERVICE_ID);
+	position = position + sizeof(guint16);
+	
+	// Length 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(guint32);
+	
+	// Command 16 bits
+	*(guint16*)&msg->message[position] = g_htons(FILE_PART);
+	position = position + sizeof(guint16);
+	
+	// Length of file contents in this message 16 bits
+	*(guint16*)&msg->message[position] = g_htons(size);
+	position = position + sizeof(guint16);
+
+	// File contents id 16 bits
+	*(guint16*)&msg->message[position] = g_htons(id);
+	position = position + sizeof(guint16);
+
+	// file contents
+	g_memmove(&msg->message[position],filecontents,size);
+	
+	return msg;
+}
+
 /**
  * gems_create_general_message:
  * @msg: Already allocated message or NULL when new #gems_message will be
