@@ -59,5 +59,11 @@ gems_message* gems_create_message_control_get_login();
 
 gems_message* gems_create_message_mentor_log_message(guint16 type, char *message);
 
+gems_message* gems_create_message_songbank_search_file_req(guint16 type, char *filename);//Type = filetype (gems_definitions.h)
+gems_message* gems_create_message_songbank_search_file_reply(guint16 type, guint16 status);
+gems_message* gems_create_message_songbank_file_req(guint16 type, char *filename);
+gems_message* gems_create_message_songbank_file_header(guint16 type, guint16 size, char *filename);
+gems_message* gems_create_message_songbank_file_part(guint16 type, guint16 size, guint16 id,char *filecontents);
+
 gems_message* gems_create_general_message(gems_message* msg, guint16 serviceid, guint32 length, guint16 type);
 #endif // __GEMS_MESSAGE_FUNCTIONS
