@@ -17,9 +17,19 @@
 #include "gems_message_functions.h"
 #include "../cem/cem.h"
 
-// Add new connection item 
+/**
+ * gems_service_jammo_process_new:
+ * @connection: new connection item to add into connection lists.
+ * 
+ * Add new @connection to list of JamMo service connections for the handshake
+ * procedure and application version verification.
+ *
+ * Returns: void
+ */ 
 void gems_service_jammo_process_new(gems_connection* connection)
 {
+	if(!connection) return;
+	
 	gems_service_jammo* data = gems_get_data()->service_jammo;
 	connection->connection_state = JAMMO_CONNECTING;
 	data->connections = g_list_append(data->connections, connection);
@@ -28,7 +38,18 @@ void gems_service_jammo_process_new(gems_connection* connection)
 	g_free(logmsg);
 }
 
-// Check the connections for messages, state changes etc.
+/**
+ * gems_service_jammo_process_connections:
+ *
+ * Process messages from connections in the handshake and version verification
+ * process. A timeout function executed periodically by the Glib main loop.
+ * Will remove self from main loop when the service is disabled or there is no
+ * connection to PeerHood. Calls gems_service_jammo_process_list() to process
+ * the incoming data from the connections in the list.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_service_jammo_process_connections()
 {	
 	gems_components* data = gems_get_data();
@@ -41,6 +62,27 @@ gint gems_service_jammo_process_connections()
 	return TRUE;
 }
 
+/**
+ * gems_service_jammo_process_list:
+ * @list: List of #gems_connection elements to process
+ * @service: The role in the handshake process, TRUE = service role
+ * 
+ * Read the incoming data from connections in the @list. Goes through ever
+ * connection element (#gems_connection) in the list and reads the incoming
+ * data in pieces into the network buffer of the connection. Removes the
+ * connections which have sent invalid data. Disconnects connections that have
+ * been idle for too long to avoid deadlocks. If the message is an error
+ * message it will be forwarded to gems_service_jammo_process_error() and all
+ * other proper messages are forwarded to gems_service_jammo_process_data(). If
+ * the connection #jammo_state is %JAMMO_CONNECTED_NO_AUTH the handshake and
+ * version verification process was successfully executed and the connection is
+ * moved to connected list and is ready to be used by other services. The
+ * connections which are in %JAMMO_VERSION_MISMATCH state are moved to rejected
+ * list.
+ *
+ * Returns: Pointer to the list that was given as parameter after it was
+ * processed.
+ */ 
 GList* gems_service_jammo_process_list(GList* list, gboolean service)
 {
 	gboolean cleanup_required = FALSE;
@@ -358,11 +400,27 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 	return list;
 }
 
+/**
+ * gems_service_jammo_process_data:
+ * @element: Connection element which has incoming data in its network buffer
+ * @service: The role in the handshake process, TRUE = service role
+ *
+ * Process the message in the network buffer of the @element in the given role
+ * (@service). This is the implementation of the state machine for verifying 
+ * the version between devices. The state of the connection is changed based on
+ * the incoming data.
+ *
+ * Returns: A #gboolean with value TRUE if there are no errors with the
+ * connection @element, FALSE when the connection @element should be removed
+ * from list.
+ */ 
 gboolean gems_service_jammo_process_data(gems_connection *element, gboolean service)
 {
 	gboolean wrongstate = FALSE;
 	gboolean success = TRUE;
 	gchar* logmsg = NULL;
+	
+	if(!element) return TRUE;
 
 	switch(element->connection_state)
 	{
@@ -567,6 +625,19 @@ gboolean gems_service_jammo_process_data(gems_connection *element, gboolean serv
 	return success;
 }
 
+/**
+ * gems_service_jammo_:
+ * @element: Connection element which has incoming data in network buffer
+ * @service: The role in the handshake process, TRUE = service role
+ *
+ * Process an error message in the network buffer of connection @element.
+ * Processes the error messages created in the handshake and version
+ * verification process in the given role (@service).
+ *
+ * Returns: A #gboolean with value TRUE if there are no errors with the
+ * connection @element, FALSE when the connection @element should be removed
+ * from list.
+ */ 
 gboolean gems_service_jammo_process_error(gems_connection *element, gboolean service)
 {
 	gems_components* data = gems_get_data();
@@ -574,6 +645,8 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 	guint16 errortype = 0;
 	gchar* logmsg = NULL;
 	
+	if(!element) return TRUE;
+	
 	// Check what service sent
 	if(gems_connection_get_16(element, (sizeof(guint16)+sizeof(guint32))) == JAMMO_SERVICE_ID)
 	{
@@ -642,6 +715,13 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 	return success;
 }
 
+/**
+ * gems_service_jammo_init:
+ *
+ * Initialize JamMo service data.
+ *
+ * Returns: pointer to new new #gems_service_jammo struct
+ */ 
 gems_service_jammo* gems_service_jammo_init()
 {
 	// JamMo service
@@ -658,6 +738,13 @@ gems_service_jammo* gems_service_jammo_init()
 	return data;
 }
 
+/**
+ * gems_service_jammo_cleanup:
+ *
+ * Clean and delete allocated #gems_service_jammo struct and its data.
+ *
+ * Returns: void
+ */ 
 void gems_service_jammo_cleanup()
 {
 	gchar* logmsg = NULL;
@@ -675,6 +762,13 @@ void gems_service_jammo_cleanup()
 	data = NULL;
 }
 
+/**
+ * gems_service_jammo_cleanup_lists:
+ *
+ * Delete connections in the initialized connections list.
+ *
+ * Returns: void
+ */ 
 void gems_service_jammo_cleanup_lists()
 {
 	gems_service_jammo* data = gems_get_data()->service_jammo;
