@@ -12,6 +12,7 @@
 #define __GEMS_SERVICE_PROFILE_
 
 #include "gems_structures.h"
+#include "gems_teacher_server_utils.h"
 
 gems_service_profile* gems_service_profile_init();
 void gems_service_profile_cleanup();
@@ -19,4 +20,9 @@ void gems_service_profile_cleanup_lists();
 
 gboolean gems_service_profile_process_request(gems_connection* element);
 gboolean gems_service_profile_process_profile_upload(gems_connection* element);
+
+//Callback for informing teacher server about incoming profile (used after profile request)
+void (*teacher_server_callback_new_profile)(jammo_profile_container* prof);
+void gems_service_profile_set_callback_profile(void (*func_ptr)(jammo_profile_container* prof) );
+
 #endif
