@@ -883,7 +883,33 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 			}
 			break;
 		case SONGBANK_SERVICE_ID:
-			break;
+			switch(gems_connection_get_16(element,6)) // command
+			{
+				case SEARCH_FILE_REQ:
+					//  Filetype 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					break;
+				case SEARCH_FILE_REPLY:
+					//  Status 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					break;
+				case FILE_REQ:
+					//  Filetype 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					break;
+				case FILE_HEADER:
+					//  Filetype 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					//  File size 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					break;
+				case FILE_PART:
+					//  File part length 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					//  id 16 bits
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
+					break;
+			}
 		case DATATRANSFER_SERVICE_ID:
 			break;
 		case MENTOR_SERVICE_ID:
