@@ -291,14 +291,27 @@ typedef struct{
 
 /**
  * gems_service_songbank:
- * @baseDirectory: ?
+ * @baseDirectory: where to search for files
  * @sbComm: The connection to song bank?
  *
  * Songbank service data
  */ 
 typedef struct{
-	char* baseDirectory;
+	gboolean enabled;
+	gchar* baseDirectory;
+	gchar* searchfile;
+	gchar* receivefile;
+	guint16 receivesize;
+	guint16 receive_id;
+	guint16 totalsize;
+	//For file to be sent
+	gchar* sendfilename;
+	gems_connection* targetconnection;
+	guint16 location;
+	guint16 part_id;
+	gboolean active;
 	SongBankComm* sbComm;
+	gint port;
 }gems_service_songbank;
 
 /**
