@@ -14,6 +14,15 @@
 #include "gems_security.h"
 #include "../configure.h"
 
+/**
+ * gems_teacher_server_new_profile_container:
+ *
+ * Create and initialize new empty #jammo_profile_container for teacher server.
+ * The same container is also used for storing the full profile when creating a
+ * temporary profile on the mobile device.
+ *
+ * Returns: A pointer to new #jammo_profile_container 
+ */
 jammo_profile_container* gems_teacher_server_new_profile_container()
 {
 	jammo_profile_container* container = g_new(jammo_profile_container,sizeof(jammo_profile_container));
@@ -37,6 +46,14 @@ jammo_profile_container* gems_teacher_server_new_profile_container()
 	return container;	
 }
 
+/**
+ * gems_teacher_server_new_profile_data_container:
+ *
+ * Create new teacher server database container structure 
+ * (#teacher_server_profile_data) and initialize its data.
+ *
+ * Returns: A pointer to new #teacher_server_profile_data structure.
+ */
 teacher_server_profile_data* gems_teacher_server_new_profile_data_container()
 {
 	teacher_server_profile_data* data = g_new(teacher_server_profile_data,sizeof(teacher_server_profile_data));
@@ -53,6 +70,14 @@ teacher_server_profile_data* gems_teacher_server_new_profile_data_container()
 	return data;
 }
 
+/**
+ * gems_teacher_server_clear_profile_container:
+ * @container: Container to clear and free
+ *
+ * Clear all conteint in the #jammo_profile_container and free it.
+ *
+ * Returns: void
+ */
 void gems_teacher_server_clear_profile_container(jammo_profile_container* container)
 {
 	if(container)
@@ -70,6 +95,14 @@ void gems_teacher_server_clear_profile_container(jammo_profile_container* contai
 	}
 }
 
+/**
+ * gems_teacher_server_clear_profile_data_container:
+ * @Data: Data container to clear and free
+ *
+ * Clear all conteint in the #teacher_server_profile_data and free it.
+ *
+ * Returns: void
+ */
 void gems_teacher_server_clear_profile_data_container(teacher_server_profile_data* data)
 {
 	if(data)
@@ -85,6 +118,25 @@ void gems_teacher_server_clear_profile_data_container(teacher_server_profile_dat
 	}	
 }
 
+/**
+ * gems_teacher_server_create_profile:
+ * @_type: Type of the profile (%PROF_TYPE_LOCAL when creating a local profile
+ * on the device or %PROF_TYPE_REMOTE when creating profile on teacher server
+ * @_userid: User id to assign to profile
+ * @_username: Username to assign to profile
+ * @_password: Plain password for en-/decrypting this profile
+ * @_authlevel: Authorization level to assign to profile
+ * @_firstname: First name of the user to assign to profile
+ * @_lastname: Last name of the user to assign to profile
+ * @_age: Age of the user to assign to profile
+ * @_avatarid: Id of the users avatar to assign to profile
+ *
+ * Create new profile with 0 points and fill it with given information. Calls
+ * gems_teacher_server_setup_profile() to create the actual profile.
+ *
+ * Returns: A pointer to new #jammo_profile_container or NULL if some data is
+ * not set or is invalid or the profile cannot be encrypted.
+ */
 jammo_profile_container* gems_teacher_server_create_profile(guint8 _type, guint32 _userid, const gchar* _username, const gchar* _password,
 	const gchar* _authlevel, const gchar* _firstname, const gchar* _lastname, guint16 _age, guint32 _avatarid)
 {
@@ -92,6 +144,29 @@ jammo_profile_container* gems_teacher_server_create_profile(guint8 _type, guint3
 	return gems_teacher_server_setup_profile(_type, _userid,_username,_password,NULL,_authlevel,_firstname,_lastname,_age,0,_avatarid);
 }
 
+/**
+ * gems_teacher_server_setup_profile:
+ * @_type: Type of the profile (%PROF_TYPE_LOCAL when creating a local profile
+ * on the device or %PROF_TYPE_REMOTE when creating profile on teacher server
+ * @_userid: User id to assign to profile
+ * @_username: Username to assign to profile
+ * @_password: Plain password for en-/decrypting this profile
+ * @_salt: Salt for password and encryption context initializations, if salt is
+ * NULL new random salt will be generated
+ * @_authlevel: Authorization level to assign to profile
+ * @_firstname: First name of the user to assign to profile
+ * @_lastname: Last name of the user to assign to profile
+ * @_age: Age of the user to assign to profile
+ * @_points: Points to set for the user
+ * @_avatarid: Id of the users avatar to assign to profile
+ *
+ * Create new profile and fill it with given information. If the salt is NULL
+ * generate new and call gems_teacher_server_encrypt_profile() to initialize
+ * the security for encrypting the profile data.
+ *
+ * Returns: A pointer to new #jammo_profile_container or NULL if some data is
+ * not set or is invalid or the profile cannot be encrypted.
+ */
 jammo_profile_container* gems_teacher_server_setup_profile(guint8 _type, guint32 _userid, const gchar* _username, const gchar* _password,
 	guchar* _salt, const gchar* _authlevel, const gchar* _firstname, const gchar* _lastname, guint16 _age, guint32 _points, guint32 _avatarid)
 {
@@ -138,6 +213,16 @@ jammo_profile_container* gems_teacher_server_setup_profile(guint8 _type, guint32
 	}
 }
 
+/**
+ * gems_teacher_server_get_profile_for_user:
+ * @data: Teacher server "database" to use for searching the profile
+ * @username: Searches a profile for this username
+ *
+ * Search the database @data for occurance of profile with @username. Return a
+ * pointer to it or NULL if not found.
+ *
+ * Returns: A pointer to #jammo_profile_container or NULL if not found.
+ */
 jammo_profile_container* gems_teacher_server_get_profile_for_user(teacher_server_profile_data* data, gchar* username)
 {
 	GList* iter = NULL;
@@ -153,6 +238,16 @@ jammo_profile_container* gems_teacher_server_get_profile_for_user(teacher_server
 	return NULL;
 }
 
+/**
+ * gems_teacher_server_get_profile_for_user_id:
+ * @data: Teacher server "database" to use for searching the profile
+ * @userid: Searches a profile for this userid
+ *
+ * Search the database @data for occurance of profile the @userid. Return a
+ * pointer to it or NULL if not found. Useful for checking for duplicate ids.
+ *
+ * Returns: A pointer to #jammo_profile_container or NULL if not found.
+ */
 jammo_profile_container* gems_teacher_server_get_profile_for_user_id(teacher_server_profile_data* data, guint32 userid)
 {
 	GList* iter = NULL;
@@ -168,6 +263,22 @@ jammo_profile_container* gems_teacher_server_get_profile_for_user_id(teacher_ser
 	return NULL;
 }
 
+/**
+ * gems_teacher_server_encrypt_profile:
+ * @container: The container containing data to encrypt
+ *
+ * Encrypt the content of the @container and set the encrypted profile into the
+ * encrypted profile data field of the #jammo_profile_container. Initialize the
+ * security contexts with the password and salt in the @container and encrypt
+ * the profile. Salted password and the profile are hashed. The  encrypted
+ * profile is in the same format as the profile that is stored to disk 
+ * (version, salt, password hash, profile hash and encrypted profile). Normally
+ * used through other functions (create profile & change password) - no checks 
+ * for container data.
+ *
+ * Returns: TRUE if the profile was encrypted and hashed, password hashed and 
+ * encrypted data set, FALSE otherwise.
+ */
 gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 {
 	// vars
@@ -275,6 +386,16 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 	return rval;
 }
 
+/**
+ * gems_teacher_server_change_password:
+ * @container: Profile container for which the password will be changed
+ * @password: New password
+ *
+ * Change the password for profile in @container. Set the given plain @password
+ * to @container and re-encrypt the profile with the new password.
+ *
+ * Returns: Result of gems_teacher_server_encrypt_profile().
+ */
 gboolean gems_teacher_server_change_password(jammo_profile_container* container, gchar* password)
 {	
 	if(container)
@@ -286,8 +407,20 @@ gboolean gems_teacher_server_change_password(jammo_profile_container* container,
 	else return FALSE;
 }
 
-// Write encrypted profile
-gint gems_teacher_server_write_profile(jammo_profile_container* container)
+/**
+ * gems_teacher_server_write_profile:
+ * @container: Profile to be written to disk
+ *
+ * Write the encrypted profile in the @container to disk. Profile is saved to
+ * the subfolder %JAMMOPROFILE of the folder returned by 
+ * configure_get_jammo_directory(). The profile file name is username.jpf.
+ *
+ * Returns: #GemsTUWrite type: WRITE_FAIL_CONTENT_NOT_SET for invalid 
+ * parameters, WRITE_FAIL_CANNOT_REMOVE_FILE if previous profile cannot be
+ * removed, WRITE_FAIL_CANNOT_SET_FILE_CONTENT if cannot write the encrypted
+ * data to file, WRITE_OK when profile was written to file.
+ */
+GemsTUWrite gems_teacher_server_write_profile(jammo_profile_container* container)
 {
 	if(!container) return WRITE_FAIL_CONTENT_NOT_SET;
 	if(!container->username) return WRITE_FAIL_CONTENT_NOT_SET;
@@ -328,6 +461,19 @@ gint gems_teacher_server_write_profile(jammo_profile_container* container)
 	return WRITE_OK;
 }
 
+/**
+ * gems_teacher_server_save_encrypted_profile:
+ * @username: Username on the encrypted profile data
+ * @profiledata: Encrypted profile data
+ * @datalength: Length of the encrypted data.
+ *
+ * Save a single profile to disk with given encrypted data. Creates a 
+ * #jammo_profile_container withencrypted data and calls 
+ * gems_teacher_write_profile() to write this single profile onto disk.
+ *
+ * Returns: TRUE when profile was written FALSE if profile couldn't be written
+ * to disk.
+ */
 gboolean gems_teacher_server_save_encrypted_profile(gchar* username, gchar* profiledata, guint datalength)
 {
 	gboolean rval = TRUE;
@@ -345,6 +491,20 @@ gboolean gems_teacher_server_save_encrypted_profile(gchar* username, gchar* prof
 	return rval;
 }
 
+/**
+ * gems_teacher_server_serialize_all_profiles:
+ * @list: A #GList containing pointers to #jammo_profile_container structs
+ * @length: Variable to store the length of the returned #gchar
+ *
+ * Serialize ALL profiles into one big #gchar. Integers are stored as they are
+ * based on their size, charstrings will have a 8 bit integer in before the
+ * string for storing the length of the charstring (NOTE: limitation for 
+ * charstring length is atm 255). This function will be called when the 
+ * encryption of the database is performed.
+ *
+ * Returns: A #gchar containing all profiles or NULL if there is not enough 
+ * memory to allocate.
+ */
 gchar* gems_teacher_server_serialize_all_profiles(GList* list, guint* length)
 {
 	gchar* all_profiles = NULL;
@@ -438,6 +598,18 @@ gchar* gems_teacher_server_serialize_all_profiles(GList* list, guint* length)
 	return all_profiles;
 }
 
+/**
+ * gems_teacher_server_deserialize_profiles:
+ * @list: List where deserialized profiles (#jammo_profile_container) are added
+ * @serialized_data: Profiles in serialized format
+ * @length: Length of the @serialized_data
+ *
+ * Deserialize profiles and add profiles as #jammo_profile_container to @list.
+ * This will be called after database is decrypted with 
+ * gems_teacher_server_decrypt_profiles().
+ *
+ * Returns: Pointer to given @list after modifications.
+ */
 GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_data, guint length)
 {
 	jammo_profile_container* profile = NULL;
@@ -549,7 +721,17 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 	return list;
 }
 
-// Clear list
+/**
+ * gems_teacher_server_clear_profile_list:
+ * @list: A #GList containing pointers to #jammo_profile_container structs
+ *
+ * Clear the #GList containing pointers to #jammo_profile_container structs.
+ * Will be called when clearing the #teacher_server_profile_data with 
+ * gems_teacher_server_clear_profile_data_container(). Clears and frees
+ * all #jammo_profile_container structures in the @list.
+ *
+ * Returns: void
+ */
 void gems_teacher_server_clear_profile_list(GList* list)
 {
 	if(list) g_list_foreach(list,(GFunc)gems_teacher_server_clear_profile_container,NULL);
@@ -557,18 +739,47 @@ void gems_teacher_server_clear_profile_list(GList* list)
 	list = NULL;
 }
 
-// For debugging
+/**
+ * gems_teacher_server_print_profile_list:
+ * @list: A #GList containing pointers to #jammo_profile_container structs
+ *
+ * Print profiles in @list. For debugging only.
+ *
+ * Returns: void
+ */
 void gems_teacher_server_print_profile_list(GList* list)
 {
 	if(list) g_list_foreach(list,(GFunc)gems_teacher_server_print_profile,NULL);
 }
+
+/**
+ * gems_teacher_server_print_profile:
+ * @profile: profile to print
+ *
+ * Print profile data to stdout. For debugging only.
+ *
+ * Returns: void
+ */
 void gems_teacher_server_print_profile(jammo_profile_container* profile)
 {
 	printf("%u:%s:%s:%s:%s:%s:%u:%u:%u\n",profile->userid, profile->username, profile->password,profile->authlevel,
 		profile->firstname,profile->lastname,profile->age,profile->points,profile->avatarid);
 }
 
-// serialize all data and encrypt
+/**
+ * gems_teacher_server_encrypt_profiles:
+ * @data: Teacher database
+ * @passwd: Plain password provided by teacher
+ *
+ * Serialize all data in database and encrypt the database. Every profile in
+ * the database will be put into huge #gchar by calling 
+ * gems_teacher_server_serialize_all_profiles() and the returned data is then
+ * encrypted. To write the database on to disk call 
+ * gems_teacher_server_write_profile_database(). First creates a password for
+ * encryption and intializes security context, then encrypts the data.
+ *
+ * Returns: TRUE when database encryption was success, FALSE otherwise.
+ */
 gboolean gems_teacher_server_encrypt_profiles(teacher_server_profile_data* data, const gchar* passwd)
 {
 	gboolean rval = TRUE;
@@ -584,55 +795,74 @@ gboolean gems_teacher_server_encrypt_profiles(teacher_server_profile_data* data,
 	if(data->profiles == NULL) return FALSE;	
 	
 	// serialize data
-	if((serialized = gems_teacher_server_serialize_all_profiles(data->profiles, &data->datalength)) == NULL) return FALSE;
-	
-	// init salt and passwd
-	if(data->salt == NULL) data->salt = gems_security_create_password_salt();
-	password = gems_security_create_password(passwd,data->salt);
-	
-	// init security
-	if(gems_security_init_security(password,data->salt))
+	if((serialized = gems_teacher_server_serialize_all_profiles(data->profiles, &data->datalength)) == NULL) rval = FALSE;
+	else
 	{
-		// Password hash
-		if(data->pwhash != NULL) g_free(data->pwhash);
-		hash_length = PASSLEN;
-		data->pwhash = gems_security_calculate_hash(password,&hash_length);
-		if(hash_length != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
-		
-		// Profile data hash
-		if(data->datahash != NULL) g_free(data->datahash);
-		hash_length = data->datalength;
-		data->datahash = gems_security_calculate_hash((guchar*)serialized,&hash_length);
-		if(hash_length != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
-		
-		// encrypt
-		if(data->data != NULL) g_free(data->data);
-		data->data = gems_security_encrypt_data((guchar*)serialized,&(data->datalength));
-		
-		// decrypt
-		encrypted_length = data->datalength;
-		decrypted = gems_security_decrypt_data(data->data,&encrypted_length);
-		
-		// hash decrypted
-		hash_length = encrypted_length;
-		dechash = gems_security_calculate_hash(decrypted,&hash_length);
-		if(hash_length != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
+		// init salt and passwd
+		if(data->salt == NULL) data->salt = gems_security_create_password_salt();
+		password = gems_security_create_password(passwd,data->salt);
 	
-		// verify hashes
-		if(!gems_security_verify_hash(data->datahash,dechash,SHA_HASH_LENGTH)) rval = FALSE;
-		gems_security_clear_security();
+		// init security
+		if(gems_security_init_security(password,data->salt))
+		{
+			// Password hash
+			if(data->pwhash != NULL) g_free(data->pwhash);
+			hash_length = PASSLEN;
+			data->pwhash = gems_security_calculate_hash(password,&hash_length);
+			if(hash_length != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
+		
+			// Profile data hash
+			if(data->datahash != NULL) g_free(data->datahash);
+			hash_length = data->datalength;
+			data->datahash = gems_security_calculate_hash((guchar*)serialized,&hash_length);
+			if(hash_length != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
+		
+			// encrypt
+			if(data->data != NULL) g_free(data->data);
+			data->data = gems_security_encrypt_data((guchar*)serialized,&(data->datalength));
+		
+			// decrypt
+			encrypted_length = data->datalength;
+			decrypted = gems_security_decrypt_data(data->data,&encrypted_length);
+		
+			// hash decrypted
+			hash_length = encrypted_length;
+			dechash = gems_security_calculate_hash(decrypted,&hash_length);
+			if(hash_length != SHA_HASH_LENGTH) rval = FALSE; // Invalid size hash, profile might not be valid
+	
+			// verify hashes
+			if(!gems_security_verify_hash(data->datahash,dechash,SHA_HASH_LENGTH)) rval = FALSE;
+			gems_security_clear_security();
+		}
+		else rval = FALSE;
 	}
-	else rval = FALSE;
 	
-	if(serialized != NULL) g_free(serialized);
-	if(decrypted != NULL) g_free(decrypted);
-	if(dechash != NULL) g_free(dechash);
-	if(password != NULL) g_free(password);
+	if(serialized) g_free(serialized);
+	if(decrypted) g_free(decrypted);
+	if(dechash) g_free(dechash);
+	if(password)
+	{
+		gems_guaranteed_memset(password,0,PASSLEN);
+		g_free(password);
+	}
 	
 	return rval;
 }
 
-// decrypt data-field content and add pass decrypted to deserialization
+/**
+ * gems_teacher_server_decrypt_profiles:
+ * @data: Teacher database
+ * @passwd: Plain password provided by teacher
+ *
+ * Decrypt the profiles in the #teacher_server_profile_data "data"-variable and
+ * add pass decrypted profiles to deserialization function. Use this after
+ * gems_teacher_server_read_profile_database(). Decrypted profiles will be 
+ * deserialized into the profiles list in #teacher_server_profile_data, for
+ * deserialization gems_teacher_server_deserialize_profiles() is called.
+ *
+ * Returns: TRUE when password was correct and data was decrypted, FALSE
+ * otherwise.
+ */
 gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data, const gchar* passwd)
 {
 	gboolean rval = TRUE;
@@ -644,49 +874,55 @@ gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data,
 	
 	if(!data || !passwd) return FALSE;
 	if((!data->salt) || (!data->pwhash) || (!data->datahash) || (!data->data) || (data->datalength == 0))
-		return FALSE;
-		
-	// form password
-	password = gems_security_create_password(passwd,data->salt);
-	
-	if(gems_security_init_security(password,data->salt))
+		rval = FALSE;
+	else
 	{
-		// hash pass
-		hashlength = PASSLEN;
-		pwhash = gems_security_calculate_hash(password,&hashlength);
-		if(hashlength != SHA_HASH_LENGTH) rval = FALSE;
-		
-		// password verified
-		if(gems_security_verify_hash(pwhash,data->pwhash,SHA_HASH_LENGTH))
+		// form password
+		password = gems_security_create_password(passwd,data->salt);
+	
+		if(gems_security_init_security(password,data->salt))
 		{
-			// decrypt
-			decrypted = gems_security_decrypt_data(data->data,&(data->datalength));
-			
-			// hash
-			hashlength = data->datalength;
-			dechash = gems_security_calculate_hash(decrypted,&hashlength);
+			// hash pass
+			hashlength = PASSLEN;
+			pwhash = gems_security_calculate_hash(password,&hashlength);
 			if(hashlength != SHA_HASH_LENGTH) rval = FALSE;
-			
-			// verify hash
-			if(gems_security_verify_hash(data->datahash,dechash,SHA_HASH_LENGTH))
+		
+			// password verified
+			if(gems_security_verify_hash(pwhash,data->pwhash,SHA_HASH_LENGTH))
 			{
-				if(data->profiles != NULL)
+				// decrypt
+				decrypted = gems_security_decrypt_data(data->data,&(data->datalength));
+			
+				// hash
+				hashlength = data->datalength;
+				dechash = gems_security_calculate_hash(decrypted,&hashlength);
+				if(hashlength != SHA_HASH_LENGTH) rval = FALSE;
+			
+				// verify hash
+				if(gems_security_verify_hash(data->datahash,dechash,SHA_HASH_LENGTH))
 				{
-					gems_teacher_server_clear_profile_list(data->profiles);
-					data->profiles = NULL;
+					if(data->profiles != NULL)
+					{
+						gems_teacher_server_clear_profile_list(data->profiles);
+						data->profiles = NULL;
+					}
+					// Clear own security contexts BEFORE deserializing profiles
+					gems_security_clear_security();
+					// deserialize
+					data->profiles = gems_teacher_server_deserialize_profiles(data->profiles,(gchar*)decrypted,data->datalength);
 				}
-				// Clear own security contexts BEFORE deserializing profiles
-				gems_security_clear_security();
-				// deserialize
-				data->profiles = gems_teacher_server_deserialize_profiles(data->profiles,(gchar*)decrypted,data->datalength);
+				else rval = FALSE;
 			}
 			else rval = FALSE;
 		}
 		else rval = FALSE;
 	}
-	else rval = FALSE;
 	
-	if(password) g_free(password);
+	if(password)
+	{
+		gems_guaranteed_memset(password,0,PASSLEN);
+		g_free(password);
+	}
 	if(pwhash) g_free(pwhash);
 	if(decrypted) g_free(decrypted);
 	if(dechash) g_free(dechash);
@@ -694,8 +930,18 @@ gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data,
 	return rval;
 }
 
-// write encrypted data to disk
-gint gems_teacher_server_write_profile_database(teacher_server_profile_data* data)
+/**
+ * gems_teacher_server_write_profile_database:
+ * @data: Teacher database
+ *
+ * Write encrypted data to disk from database, will return 
+ * %WRITE_FAIL_CONTENT_NOT_SET if data is not encrypted. Encrypt database 
+ * before calling this with gems_teacher_server_encrypt_profiles(). Database
+ * will be written to configure_get_jammo_directory()/%TSRV_DATABASE. 
+ *
+ * Returns: #GemsTUWrite value.
+ */
+GemsTUWrite gems_teacher_server_write_profile_database(teacher_server_profile_data* data)
 {
 	if(!data) return WRITE_FAIL_CONTENT_NOT_SET;
 	if(!data->salt) return WRITE_FAIL_CONTENT_NOT_SET;
@@ -753,8 +999,17 @@ gint gems_teacher_server_write_profile_database(teacher_server_profile_data* dat
 	return WRITE_OK;
 }
 
-// read the database from disk
-gint gems_teacher_server_read_profile_database(teacher_server_profile_data** data)
+/**
+ * gems_teacher_server_write_profile_database:
+ * @data: Teacher database
+ *
+ * Read the encrypted database from the disk from directory 
+ * configure_get_jammo_directory()/%TSRV_DATABASE. When %READ_OK is returned
+ * decrypt the database with gems_teacher_server_decrypt_profiles().
+ *
+ * Returns: GemsTURead value.
+ */
+GemsTURead gems_teacher_server_read_profile_database(teacher_server_profile_data** data)
 {
 	gchar* filename = g_build_filename(configure_get_jammo_directory(),TSRV_DATABASE,NULL);
 	gchar* contents = NULL;
@@ -809,9 +1064,3 @@ gint gems_teacher_server_read_profile_database(teacher_server_profile_data** dat
 
 	return rval;
 }
-
-// TODO list profiles on disk
-// TODO load profiles on disk to jammo_profile_container*
-// TODO search profile by username & password hash
-// TODO process profile request
-// TODO send profile to user (use jammo_profile_container*
