@@ -3,7 +3,7 @@
  *
  * This file is part of JamMo.
  *
- * (c) 2009-2010 University of Oulu, Lappeenranta University of Technology
+ * (c) 2009-2011 University of Oulu, Lappeenranta University of Technology
  *
  * Authors: Jussi Laakkonen <jussi.laakkonen@lut.fi>
  */
@@ -15,6 +15,21 @@
 #include "gems_message_functions.h"
 #include "../cem/cem.h"
 
+/**
+ * gems_new_group_info:
+ * @id: Id for the group
+ * @owner: User id of the group owner (creators id)
+ * @type: Group type
+ * @size: Amount of uses in this group
+ * @spaces: Open spaces for other users
+ * @theme: Id of the theme for this group
+ * @starttimer: Whether to start the group advert timer or not (TRUE = start)
+ *
+ * Create new #gems_group_info structure with given information. Start the
+ * advert timer if @starttimer is TRUE.
+ *
+ * Returns: A pointer to created #gems_group_info.
+ */
 // TODO add group lock type as parameter
 gems_group_info* gems_new_group_info(guint32 id, guint32 owner, gint16 type, gint16 size, gint16 spaces, gint16 theme, gboolean starttimer)
 {
@@ -39,6 +54,14 @@ gems_group_info* gems_new_group_info(guint32 id, guint32 owner, gint16 type, gin
 	return info;
 }
 
+/**
+ * gems_clear_group_info:
+ * @info: Group info to clear
+ *
+ * Free group information struct.
+ *
+ * Returns: void
+ */
 void gems_clear_group_info(gems_group_info* info)
 {
 	if(info->group_advert_timer != NULL) g_timer_destroy(info->group_advert_timer);
@@ -46,8 +69,14 @@ void gems_clear_group_info(gems_group_info* info)
 	info = NULL;
 }
 
-
-// Returns -1 when the info cannot be accessed
+/**
+ * gems_group_get_spaces:
+ *
+ * Get the amount of free spaces on the current group of the user.
+ *
+ * Returns: Amount of free spaces in the current group or -1 if user is not in
+ * any group or group information does not exist.
+ */
 gint gems_group_get_spaces()
 {
 	/*gint16 spaces = info->size - 1; // Remove self
@@ -62,6 +91,14 @@ gint gems_group_get_spaces()
 	else return -1;
 }
 
+/**
+ * gems_reset_group_info:
+ *
+ * Reset the active group information. Sets all to default values and own state
+ * to %NOT_ACTIVE.
+ *
+ * Returns: void
+ */
 void gems_reset_group_info()
 {
 	// TODO if the group is active or there are other people in the group inform them
@@ -96,6 +133,14 @@ void gems_reset_group_info()
 	g_free(logmsg);
 }
 
+/**
+ * gems_group_is_in_group:
+ * @id: User id to search from group
+ *
+ * Check if the user with given @id is in the current group.
+ *
+ * Returns: TRUE if user is in the group, FALSE otherwise.
+ */
 gboolean gems_group_is_in_group(guint32 id)
 {
 	if(gems_get_data()->service_group == NULL) return FALSE;
@@ -109,7 +154,16 @@ gboolean gems_group_is_in_group(guint32 id)
 	return FALSE;
 }
 
-gint gems_group_add_to_group(guint32 id)
+/**
+ * gems_group_add_to_group:
+ * @id: User to add to group
+ *
+ * Add new user with @id to group. User will be added if there are spaces left.
+ *
+ * Returns: #GemsGroupAction types: %CANNOT_ADD, %GROUP_FULL, %ADDED_TO_GROUP
+ * or %ALREADY_IN_GROUP.
+ */
+GemsGroupAction gems_group_add_to_group(guint32 id)
 {
 	gint i = 0;
 	
@@ -144,13 +198,23 @@ gint gems_group_add_to_group(guint32 id)
 	return CANNOT_ADD; // No free slot found - should not happen! 
 }
 
-gint gems_group_remove_from_group(guint32 id)
+/**
+ * gems_group_remove_from_group:
+ * @id: User to be removed from group
+ *
+ * Remove user with @id from the current group. Free space counter is
+ * incremented with one after successful removal of user.
+ *
+ * Returns: #GemsGroupAction types: %ERROR_CANNOT_EXEC, %REMOVED_OK or 
+ * %NOT_IN_GROUP.
+ */
+GemsGroupAction gems_group_remove_from_group(guint32 id)
 {
-	if(gems_get_data()->service_group == NULL) return -1;
+	if(gems_get_data()->service_group == NULL) return ERROR_CANNOT_EXEC;
 	
 	gems_group_info* info = gems_get_data()->service_group->group_info;
 	
-	if(info == NULL) return -1;
+	if(info == NULL) return ERROR_CANNOT_EXEC;
 	
 	gint i = 0;
 	for(i = 0; i < (info->size -1); i++)
@@ -165,7 +229,16 @@ gint gems_group_remove_from_group(guint32 id)
 	return NOT_IN_GROUP;
 }
 
-// Lock and unlock group - for games/group works
+/**
+ * gems_group_lock_group:
+ * @locked: Lock state for group, TRUE = lock, FALSE = unlock
+ *
+ * Set new @locked state for the active group. Nothing will be done if the user
+ * is not the owner of the current group. A notification is sent to every other
+ * group member about the locking state change.
+ *
+ * Returns: void
+ */
 void gems_group_lock_group(gboolean locked)
 {
 	gchar* logmsg = NULL;
@@ -221,6 +294,13 @@ void gems_group_lock_group(gboolean locked)
 	// TODO notify chum that group lock has changed
 }
 
+/**
+ * gems_group_is_locked:
+ *
+ * Check if the current group is locked.
+ *
+ * Returns: TRUE when group is locked, FALSE when not locked.
+ */
 gboolean gems_group_is_locked()
 {
 	if(gems_get_data()->service_group == NULL) return FALSE;
@@ -232,6 +312,13 @@ gboolean gems_group_is_locked()
 	return info->is_locked;
 }
 
+/**
+ * gems_group_active:
+ *
+ * Check if the user is in active group (in state %IN_GROUP).
+ *
+ * Returns: TRUE when user is in active group, FALSE otherwise.
+ */
 gboolean gems_group_active()
 {
 	if(gems_get_data()->service_group == NULL) return FALSE;
@@ -245,6 +332,14 @@ gboolean gems_group_active()
 	else return FALSE;
 }
 
+/**
+ * gems_group_send_to_group:
+ * @msg: Message to be sent to group members
+ *
+ * Sends a message @msg to every group member.
+ *
+ * Returns: 1 if no errors occur, -1 otherwise.
+ */
 gint gems_group_send_to_group(gems_message* msg)
 {
 	gint i = 0;
@@ -315,6 +410,21 @@ gint gems_group_send_to_group(gems_message* msg)
 	return rval; // TODO create real return values to correspond error situations
 }
 
+/**
+ * gems_group_update_group_list:
+ * @list: Group list to update, must contain pointers to #gems_group_info
+ * structures
+ * @gid: Group to update
+ * @sender: Sender of the message (owner)
+ * @type: Type of the group
+ * @size: Group size
+ * @space: Available spaces on group
+ * @theme: Id of the theme of the group
+ *
+ * Add new or update existing group with @gid to @list of group advertisements.
+ *
+ * Returns: A pointer to given @list after modifications.
+ */
 // TODO add group lock type to parameters
 GList* gems_group_update_group_list(GList* list, guint32 gid, guint32 sender, gint16 type, gint16 size, gint16 space, gint16 theme)
 {
@@ -343,6 +453,14 @@ GList* gems_group_update_group_list(GList* list, guint32 gid, guint32 sender, gi
 	return list;
 }
 
+/**
+ * gems_group_list_other_groups:
+ *
+ * Get a copy of the group advetisement list. The list can be free'd as it is
+ * only a copy, data must be left intact.
+ *
+ * Returns: A pointer to shallow copy of the group advertisement list.
+ */
 GList* gems_group_list_other_groups()
 {
 	if(gems_get_data()->service_group == NULL) return NULL;
@@ -351,6 +469,15 @@ GList* gems_group_list_other_groups()
 	return g_list_copy(gems_get_data()->service_group->other_groups);
 }
 
+/**
+ * gems_group_get_owner_for_group:
+ * @list: List containing group advertisements (#gems_group_info)
+ * @gid: Group id to use for searching
+ *
+ * Search owner for given group with @gid from the @list.
+ *
+ * Returns: Group owners id or 0 if not found.
+ */
 guint32 gems_group_get_owner_for_group(GList* list, guint32 gid)
 {
 	GList* iterator = NULL;
@@ -368,38 +495,82 @@ guint32 gems_group_get_owner_for_group(GList* list, guint32 gid)
 	return 0;
 }
 
-/* Pair game */
+/**
+ * gems_group_create_pair_game:
+ * @theme: Id of the theme to use
+ *
+ * Initialize group for pair game with @theme.
+ *
+ * Returns: TRUE when group was created, FALSE otherwise.
+ */
 gboolean gems_group_create_pair_game(gint16 theme)
 {
 	return gems_group_init_group(GROUP_TYPE_PAIR,2,theme);
 }
 
-/* Workshop non real time 
-   NOT IMPLEMENTED */
+/**
+ * gems_group_create_workshop_non_rt:
+ * @theme: Id of the theme to use
+ *
+ * Initialize group for non realtime workshop with @theme using 4 slots.
+ *
+ * Returns: TRUE when group was created, FALSE otherwise.
+ */
 gboolean gems_group_create_workshop_non_rt(gint16 theme)
 {
-	return FALSE;
+	return gems_group_init_group(GROUP_TYPE_WS_NON_RT,4,theme);
 }
 
-/* Workshop real time - limited to 2 players only: jamming? 
-   NOT IMPLEMENTED */
+/**
+ * gems_group_create_workshop_rt:
+ * @theme: Id of the theme to use
+ * 
+ * Initialize group for realtime workshop with @theme using 2 slots.
+ *
+ * Returns: TRUE when group was created, FALSE otherwise.
+ */
 gboolean gems_group_create_workshop_rt(gint16 theme)
 {
-	return FALSE;
+	return gems_group_init_group(GROUP_TYPE_WS_RT,2,theme);
 }
 
-/* Workshop through network NOT IMPLEMENTED */
+/**
+ * gems_group_create_workshop_net:
+ * @theme: Id of the theme to use
+ * 
+ * Initialize group for networked workshop with @theme using 4 slots.
+ *
+ * Returns: TRUE when group was created, FALSE otherwise.
+ */
 gboolean gems_group_create_workshop_net(gint16 theme)
 {
-	return FALSE;
+	return gems_group_init_group(GROUP_TYPE_WS_NET,4,theme);
 }
 
-/* Chain composition game NOT IMPLEMENTED */
+/**
+ * gems_group_create_chain_game:
+ * @theme: Id of the theme to use
+ *
+ * NOT IMPLEMENTED.
+ *
+ * Returns: FALSE
+ */
 gboolean gems_group_create_chain_game(gint16 theme)
 {
 	return FALSE;
 }
 
+/**
+ * gems_group_init_group:
+ * @type: Type of the group to initialize
+ * @size: Size of the group to initialize
+ * @theme: Id of the theme of the group to initialize
+ *
+ * Initialize group with given information. Start the group adverting function
+ * (add it to Glib main loop for periodic execution).
+ * 
+ * Returns: TRUE when group was created, FALSE otherwise.
+ */
 gboolean gems_group_init_group(gint16 type, gint16 size, gint16 theme)
 {
 	gems_components* data = gems_get_data();
@@ -430,19 +601,22 @@ gboolean gems_group_init_group(gint16 type, gint16 size, gint16 theme)
 	}
 }
 
-/* gems_group_join_to_group - Join to given group
+/** gems_group_join_to_group:
+ * @gid: group id where to join
  *
- * Parameter: guint32 gid - group id
+ * Join to given group with @gid. Sends a join request to group owner and sets
+ * the user into %JOINING state.
  *
- * Returns: GROUP_LOCKED, ALREADY_IN_GROUP, NO_MATCHING_GROUP, NO_OWNER, CANNOT_CONNECT_TO_OWNER, 
- *          REQUEST_SENT, REQUEST_NOT_SENT, -1 (error)
+ * Returns: #GemsGroupAction types %GROUP_LOCKED, %ALREADY_IN_GROUP, 
+ * %NO_MATCHING_GROUP, %NO_OWNER, %CANNOT_CONNECT_TO_OWNER, %REQUEST_SENT,
+ * %REQUEST_NOT_SENT or %ERROR_CANNOT_EXEC.
  */
-gint gems_group_join_to_group(guint32 gid)
+GemsGroupAction gems_group_join_to_group(guint32 gid)
 {	
 	gems_components* data = gems_get_data();
 	
-	if(data->service_group == NULL) return -1;
-	if(data->service_group->group_info == NULL) return -1;
+	if(data->service_group == NULL) return ERROR_CANNOT_EXEC;
+	if(data->service_group->group_info == NULL) return ERROR_CANNOT_EXEC;
 	
 	if(data->service_group->group_info->is_locked == TRUE) return GROUP_LOCKED;
 	
@@ -486,17 +660,21 @@ gint gems_group_join_to_group(guint32 gid)
 	}
 }
 
-/* gems_group_leave_from_group - Leave from current group
+/** gems_group_leave_from_group:
  *
- * Returns: NOT_IN_GROUP, CANNOT_CONNECT_TO_OWNER, REQUEST_SENT, REQUEST_NOT_SENT, -1 (error)
+ * Leave from current group. Sends a leave request to group owner and sets the
+ * user to %LEAVING state.
+ *
+ * Returns: #GemsGroupAction types %NOT_IN_GROUP, %CANNOT_CONNECT_TO_OWNER,
+ * %REQUEST_SENT, %REQUEST_NOT_SENT or %ERROR_CANNOT_EXEC.
  */
-gint gems_group_leave_from_group()
+GemsGroupAction gems_group_leave_from_group()
 {
 	gems_components* data = gems_get_data();
 	gems_message* msg = NULL;
 	
-	if(data->service_group == NULL) return -1;
-	if(data->service_group->group_info == NULL) return -1;
+	if(data->service_group == NULL) return ERROR_CANNOT_EXEC;
+	if(data->service_group->group_info == NULL) return ERROR_CANNOT_EXEC;
 	
 	// Group not active
 	if(data->service_group->group_info->id == NOT_ACTIVE) return NOT_IN_GROUP;
@@ -572,6 +750,15 @@ gint gems_group_leave_from_group()
 	}
 }
 
+/**
+ * gems_group_disconnected_member_detected:
+ * @id: User id of the disconnected member
+ *
+ * Remove the user with @id from the active group when the connection to the
+ * user was disconnected. Inform other members about a disconnection.
+ *
+ * Returns: void
+ */
 void gems_group_disconnected_member_detected(guint32 id)
 {
 	gchar* logmsg = NULL;
@@ -600,6 +787,16 @@ void gems_group_disconnected_member_detected(guint32 id)
 	}
 }
 
+/**
+ * gems_group_get_gid:
+ * @group: Group info where to get the information or NULL if requesting own
+ * active group information.
+ *
+ * Get id from the given @group or from own active group if @group is NULL.
+ *
+ * Returns: Id of the group as #guint32 or 0 if the information cannot be
+ * accessed.
+ */
 guint32 gems_group_get_gid(gems_group_info* group)
 {
 	if(group == NULL)
@@ -611,6 +808,17 @@ guint32 gems_group_get_gid(gems_group_info* group)
 	else return group->id;
 }
 
+/**
+ * gems_group_get_owner:
+ * @group: Group info where to get the information or NULL if requesting own
+ * active group information.
+ *
+ * Get the id of the owner for given @group or for own active group if @group
+ * is NULL.
+ *
+ * Returns: Id of the owner of the group as #guint32 or 0 if the data cannot be
+ * accessed.
+ */
 guint32 gems_group_get_owner(gems_group_info* group)
 {
 	if(group == NULL)
@@ -622,6 +830,15 @@ guint32 gems_group_get_owner(gems_group_info* group)
 	else return group->owner;
 }
 
+/**
+ * gems_group_get_type:
+ * @group: Group info where to get the information or NULL if requesting own
+ * active group information.
+ *
+ * Get the type of the given @group or from own active group if @group is NULL.
+ *
+ * Returns: Group type as #gint16 or 0 if the information cannot be accessed.
+ */
 gint16 gems_group_get_type(gems_group_info* group)
 {
 	if(group == NULL)
@@ -633,6 +850,16 @@ gint16 gems_group_get_type(gems_group_info* group)
 	else return group->type;
 }
 
+/**
+ * gems_group_get_theme:
+ * @group: Group info where to get the information or NULL if requesting own
+ * active group information.
+ *
+ * Get the theme of the given @group or from own active group if @group is 
+ * NULL.
+ *
+ * Returns: Group theme as #gint16 or 0 if the information cannot be accessed.
+ */
 gint16 gems_group_get_theme(gems_group_info* group)
 {
 	if(group == NULL)
@@ -644,6 +871,16 @@ gint16 gems_group_get_theme(gems_group_info* group)
 	else return group->theme;
 }
 
+/**
+ * gems_group_get:
+ * @group: Group info where to get the information or NULL if requesting own
+ * active group information.
+ *
+ * Get the size of the given @group or the size of own active group if @group
+ * is NULL.
+ *
+ * Returns: Group size as #gint16 or 0 if the information cannot be accessed.
+ */
 gint16 gems_group_get_size(gems_group_info* group)
 {
 	if(group == NULL)
@@ -655,6 +892,17 @@ gint16 gems_group_get_size(gems_group_info* group)
 	else return group->size;
 }
 
+/**
+ * gems_group_get:
+ * @group: Group info where to get the information or NULL if requesting own
+ * active group information.
+ *
+ * Get the amount of free spaces in the given @group or from own active group
+ * if the @group is NULL.
+ *
+ * Returns: The amount of free spaces left, 0 also when information cannot be
+ * accessed.
+ */
 gint16 gems_group_get_spaces_left(gems_group_info* group)
 {
 	if(group == NULL)
@@ -666,6 +914,14 @@ gint16 gems_group_get_spaces_left(gems_group_info* group)
 	else return group->spaces;
 }
 
+/**
+ * gems_group_get_group_members:
+ *
+ * Get all members in the active group.
+ *
+ * Returns: A pointer to #guint32 array of user ids in the active group or NULL
+ * if the information cannot be accessed.
+ */
 guint32* gems_group_get_group_members()
 {
 	if(gems_get_data()->service_group == NULL) return NULL;
