@@ -390,7 +390,11 @@ static void create_group(GtkWidget *widget)
 		for(int i=1;i<no_players;i++)
 		{
 			newgroup->peers[i-1] =player_ids[i];
+			printf("player[%i] = %i\n",i,player_ids[i]);
 		}
+		//newgroup->peers[0] =1002;
+		//newgroup->peers[1] =12346;
+		//newgroup->peers[2] =12347;
 		msg = gems_create_message_group_management_group_info_teacher(FORCE_GROUP, newgroup, 0);
 		element = gems_communication_get_connection_with_userid(gems_get_data()->communication->connections, ownerid);
 		if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
@@ -409,6 +413,7 @@ static void create_group(GtkWidget *widget)
 				if(i!=j)
 				{
 					newgroup->peers[p] =player_ids[j];
+					printf("player[%i] = %i\n",p,player_ids[j]);					
 					p++;
 				}
 			}
@@ -585,6 +590,112 @@ static void set_profile(GtkWidget *widget)
 	g_free(lastname);
 }
 
+static void set_all_profiles(GtkWidget *widget)
+{
+	jammo_profile_container* profile_container;
+	guint32 userid, avatarid;
+	guint16 age;
+	gchar *username, *password, *authlevel, *firstname, *lastname;
+	gems_message* msg;
+	gems_connection* element = NULL;
+	GList* selections = NULL;
+	GtkTreeIter treeiter;
+	GtkTreeModel *model;
+	guint32 selected_id,i;
+	char* logmsg;
+
+
+
+	//Send to all users without a profile
+	GList* iter = NULL;
+	gems_peer_profile* prof = NULL;
+	i=1;
+	for(iter = g_list_first(connections); iter; iter = g_list_next(iter))
+	{
+		prof = gems_get_profile((gems_connection*)iter->data); // Get profile
+		
+		if(prof == NULL) 
+		{
+			element = (gems_connection*)iter->data;	
+			
+			GRand* grand = g_rand_new_with_seed(time(NULL)+i);
+			userid = g_rand_int(grand)%10000;
+			//userid=1000+i;			
+			g_rand_free(grand);
+			avatarid = 1;
+			age = 1;
+			username = g_strdup_printf("defaultuser%d",i);
+			password = g_strdup_printf("password");
+			authlevel = g_strdup_printf("1");
+			firstname = g_strdup_printf("default");
+			lastname = g_strdup_printf("user");
+
+			printf("Sending profile for %s\n",username);
+
+			profile_container = gems_teacher_server_create_profile(PROF_TYPE_REMOTE,userid, username, password, authlevel, firstname,lastname, age, avatarid);
+			
+			//Profile info
+			msg = gems_create_message_teacher_service_profile_reply(profile_container->encrypted, profile_container->encrypted_length, username);
+			
+			if(element != NULL)
+			{
+
+				if(gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN, element, msg) == FALSE)
+				{
+					logmsg = g_strdup_printf("lock device: cannot send message to user %d",selected_id);
+					cem_add_to_log(logmsg,J_LOG_ERROR);
+					g_free(logmsg);
+				}
+				gems_clear_message(msg);
+
+				//Set new profile into login profile
+				msg = gems_create_message_control_set_login_name(username);
+				if(gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN, element, msg) == FALSE)
+				{
+					logmsg = g_strdup_printf("lock device: cannot send message to user %d",selected_id);
+					cem_add_to_log(logmsg,J_LOG_ERROR);
+					g_free(logmsg);
+				}
+				gems_clear_message(msg);
+
+				//Login with new profile
+				msg = gems_create_message_control_force_login(password, strlen(password));
+				if(gems_communication_write_encrypted_data(JAMMO_PACKET_ADMIN, element, msg) == FALSE)
+				{
+					logmsg = g_strdup_printf("lock device: cannot send message to user %d",selected_id);
+					cem_add_to_log(logmsg,J_LOG_ERROR);
+					g_free(logmsg);
+				}
+				gems_clear_message(msg);
+
+
+				if (element->profile == NULL)
+				{
+					element->profile = gems_new_peer_profile(username, userid, age, avatarid);
+					logmsg = g_strdup_printf("Set profile to unknown user");
+					cem_add_to_log(logmsg,J_LOG_DEBUG);
+					g_free(logmsg);
+				}
+				else
+				{
+					gems_peer_profile_set_values(element->profile, username, userid, age, avatarid);
+					logmsg = g_strdup_printf("Set profile to old user");
+					cem_add_to_log(logmsg,J_LOG_DEBUG);
+					g_free(logmsg);
+				}
+			}
+
+			i++;
+			g_free(username);
+			g_free(password);
+			g_free(authlevel);
+			g_free(firstname);
+			g_free(lastname);
+		}
+	}
+
+}
+
 static void get_profile(GtkWidget *widget)
 {
 	gems_message* msg;
@@ -697,7 +808,23 @@ static void open_group_editor(GtkWidget *widget)
 	gametype_on_changed(widget, NULL); 
 }
 
+gint close_main_window()
+{
+	gtk_main_quit();
+	return(TRUE);
+}
 
+gint close_group_window()
+{
+	gtk_widget_hide( group_window );
+	return(TRUE);
+}
+
+gint close_profile_window()
+{
+	gtk_widget_hide( profile_window );
+	return(TRUE);
+}
 int main( int    argc,
       char **argv )
 {
@@ -779,13 +906,18 @@ int main( int    argc,
     	/* Connect signals */
     	gtk_builder_connect_signals( builder, NULL );
 	
+	//Window close buttons
+	g_signal_connect(mainwindow, "destroy", G_CALLBACK(close_main_window), NULL);
+	g_signal_connect(group_window, "destroy", G_CALLBACK(close_group_window), NULL);
+	g_signal_connect(profile_window, "destroy", G_CALLBACK(close_profile_window), NULL);
+
 	g_signal_connect(gtk_builder_get_object( builder, "create_group_button" ), "clicked", G_CALLBACK(open_group_editor), NULL);
 	g_signal_connect(gtk_builder_get_object( builder, "create_group_confirmation" ), "clicked", G_CALLBACK(create_group), NULL);
 	g_signal_connect(gtk_builder_get_object( builder, "edit_profile_button" ), "clicked", G_CALLBACK(edit_profile), NULL);
 	g_signal_connect(gtk_builder_get_object( builder, "set_profile_button" ), "clicked", G_CALLBACK(set_profile), NULL);
 	g_signal_connect(gtk_builder_get_object( builder, "get_profile_button" ), "clicked", G_CALLBACK(get_profile), NULL);
 	g_signal_connect(gtk_builder_get_object( builder, "lock_device_button" ), "clicked", G_CALLBACK(lock_device), NULL);
-
+	g_signal_connect(gtk_builder_get_object( builder, "set_all_profiles_button" ), "clicked", G_CALLBACK(set_all_profiles), NULL);
 
 	//Profile editor entrys
 	user_id_entry = GTK_WIDGET(gtk_builder_get_object( builder, "user_id_entry" ));
