@@ -274,7 +274,7 @@ gboolean process_data(gems_connection* c,serverdata* data)
 				// contains public profile
 				if(gems_connection_get_32(c,sizeof(guint16)) > 8)
 				{
-					guint position = 8;
+					position = 8;
 					
 					gchar* username = gems_connection_get_char(c,position);
 					position = position + strlen(username) + 1;
